==> nextcloud-25.0.5.tgz: nextcloud/lib/l10n/nn_NO.js <==
OC.L10N.register(
    "lib",
    {
    "Authentication" : "Godkjenning",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "Files" : "Filer",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"],
    "last month" : "førre månad",
    "_%n month ago_::_%n months ago_" : ["%n månad sidan","%n månadar sidan"],
    "last year" : "i fjor",
    "_%n year ago_::_%n years ago_" : ["%n år sidan","%n år sidan"],
    "_%n hour ago_::_%n hours ago_" : ["%n time sidan","%n timar sidan"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minutt sidan","%n minutt sidan"],
    "seconds ago" : "sekund sidan",
    "File name is too long" : "Filnamnet er for langt",
    "__language_name__" : "Nynorsk",
    "Help" : "Hjelp",
    "Apps" : "Appar",
    "Settings" : "Instillingar",
    "Log out" : "Logg ut",
    "Users" : "Brukarar",
    "Email" : "Epost",
    "Phone" : "Telefonnummer",
    "Address" : "Adresse",
    "Profile picture" : "Profilbilete",
    "About" : "Om",
    "Full name" : "Fult namn",
    "Unknown user" : "Ukjend brukar",
    "Additional settings" : "Tilleggsinnstillingar",
    "Set an admin password." : "Vel eit admin-passord.",
    "Open »%s«" : "Opna »%s«",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Må",
    "Tu" : "Ty",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "La",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "User disabled" : "Brukar deaktivert",
    "Login canceled by app" : "Innlogging avbroten av app",
    "Authentication error" : "Feil i autentisering"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.7p0.tgz: nextcloud/lib/l10n/nn_NO.js <==
OC.L10N.register(
    "lib",
    {
    "Authentication" : "Godkjenning",
    "Unknown filetype" : "Ukjend filtype",
    "Invalid image" : "Ugyldig bilete",
    "Files" : "Filer",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"],
    "last month" : "førre månad",
    "_%n month ago_::_%n months ago_" : ["%n månad sidan","%n månadar sidan"],
    "last year" : "i fjor",
    "_%n year ago_::_%n years ago_" : ["%n år sidan","%n år sidan"],
    "_%n hour ago_::_%n hours ago_" : ["%n time sidan","%n timar sidan"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minutt sidan","%n minutt sidan"],
    "seconds ago" : "sekund sidan",
    "File name is too long" : "Filnamnet er for langt",
    "__language_name__" : "Nynorsk",
    "Help" : "Hjelp",
    "Apps" : "Appar",
    "Settings" : "Instillingar",
    "Log out" : "Logg ut",
    "Users" : "Brukarar",
    "Email" : "Epost",
    "Phone" : "Telefonnummer",
    "Address" : "Adresse",
    "Profile picture" : "Profilbilete",
    "About" : "Om",
    "Unknown user" : "Ukjend brukar",
    "Additional settings" : "Tilleggsinnstillingar",
    "Set an admin password." : "Vel eit admin-passord.",
    "Open »%s«" : "Opna »%s«",
    "Sunday" : "Søndag",
    "Monday" : "Måndag",
    "Tuesday" : "Tysdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Laurdag",
    "Sun." : "Søn.",
    "Mon." : "Mån.",
    "Tue." : "Tys.",
    "Wed." : "Ons.",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lau.",
    "Su" : "Su",
    "Mo" : "Må",
    "Tu" : "Ty",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "La",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar,",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "User disabled" : "Brukar deaktivert",
    "Login canceled by app" : "Innlogging avbroten av app",
    "Authentication error" : "Feil i autentisering",
    "Full name" : "Fult namn"
},
"nplurals=2; plural=(n != 1);");
